| Title: | Time Series Autoregressive-Based Decomposition |
|---|---|
| Description: | Autoregressive-based decomposition of a time series based on the approach in West (1997). Particular cases include the extraction of trend and seasonal components. |
| Authors: | Susana Barbosa |
| Maintainer: | Susana Barbosa <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 2.1-1 |
| Built: | 2026-05-20 07:46:35 UTC |
| Source: | https://github.com/cran/ArDec |
Decomposition of a time series into latent subseries from a fitted autoregressive model
ardec(x, coef, ...)ardec(x, coef, ...)
x |
time series |
coef |
autoregressive parameters of AR(p) model |
... |
additional arguments for specific methods |
If an observed time series can be adequately described by an (eventually high order) autoregressive AR(p) process, a constructive result (West, 1997) yields a time series decomposition in terms of latent components following either AR(1) or AR(2) processes depending on the eigenvalues of the state evolution matrix.
Complex eigenvalues r exp(iw) correspond to pseudo-periodic oscillations as a damped sine wave with fixed period (2pi/w) and damping factor r. Real eigenvalues correspond to a first order autoregressive process with parameter r.
A list with components:
period |
periods of latent components |
modulus |
damping factors of latent components |
comps |
matrix of latent components |
S. M. Barbosa
West, M. (1997), Time series decomposition. Biometrika, 84, 489-494.
West, M. and Harrisson, P.J. (1997), Bayesian Forecasting and Dynamic Models, Springer-Verlag.
data(tempEng) coef=ardec.lm(tempEng)$coefficients # warning: running the next command can be time comsuming! decomposition=ardec(tempEng,coef)data(tempEng) coef=ardec.lm(tempEng)$coefficients # warning: running the next command can be time comsuming! decomposition=ardec(tempEng,coef)
Function ardec.lm fits an autoregressive model of order p, AR(p) to a time series through a linear least squares regression.
ardec.lm(x)ardec.lm(x)
x |
time series |
For ardec.lm, an object of class "lm".
S. M. Barbosa
West, M. (1995), Bayesian inference in cyclical component dynamic linear models.Journal of the American Statistical Association, 90, 1301-1312.
data(tempEng) model=ardec.lm(tempEng)data(tempEng) model=ardec.lm(tempEng)
Function ardec.periodic extracts a periodic component from the autoregressive decomposition of a monthly time series.
ardec.periodic(x, per, tol = 0.95)ardec.periodic(x, per, tol = 0.95)
x |
time series |
per |
period of the component to be extracted |
tol |
tolerance for the period of the component |
A list with components:
period |
period for the anual component |
modulus |
damping factor for the annual component |
component |
extracted component |
S. M. Barbosa
data(tempEng) ardec.periodic(tempEng,per=12)data(tempEng) ardec.periodic(tempEng,per=12)
Function ardec.trend extracts the trend component from the autoregressive decomposition of a monthly time series.
ardec.trend(x)ardec.trend(x)
x |
time series |
A list with components:
modulus |
damping factor for the annual component |
trend |
trend component |
S. M. Barbosa
data(co2) ardec.trend(co2)data(co2) ardec.trend(co2)
Monthly temperature in Central England from 1723-1970
data(tempEng)data(tempEng)
Time-Series [1:2976] from 1723 to 1971
Hipel, K. W. and Mcleod, A. (1994) Time Series Modelling of Water Resources and Environmental Systems, Elsevier
data(tempEng)data(tempEng)